mailr4038 - /branches/N_state_model/generic_fns/align_tensor.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 26, 2007 - 16:47:
Author: bugman
Date: Mon Nov 26 16:36:29 2007
New Revision: 4038

URL: http://svn.gna.org/viewcvs/relax?rev=4038&view=rev
Log:
Updated the docstring of the generic_fns.align_tensor.set() function.


Modified:
    branches/N_state_model/generic_fns/align_tensor.py

Modified: branches/N_state_model/generic_fns/align_tensor.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/N_state_model/generic_fns/align_tensor.py?rev=4038&r1=4037&r2=4038&view=diff
==============================================================================
--- branches/N_state_model/generic_fns/align_tensor.py (original)
+++ branches/N_state_model/generic_fns/align_tensor.py Mon Nov 26 16:36:29 
2007
@@ -752,7 +752,7 @@
 
 def set(value=None, param=None):
     """
-    Diffusion tensor set details
+    Alignment tensor set details
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     If the alignment tensor has not been setup, use the more powerful 
function
@@ -761,37 +761,22 @@
     The alignment tensor parameters can only be set when the run corresponds 
to model-free
     analysis.  The units of the parameters are:
 
-        Inverse seconds for tm.
-        Seconds for Diso, Da, Dx, Dy, Dz, Dpar, Dper.
-        Unitless for Dratio and Dr.
-        Radians for all angles (alpha, beta, gamma, theta, phi).
+        Hertz for Axx, Ayy, Azz, Axxyy, Axy, Axz, Ayz.
+        Radians for all angles (alpha, beta, gamma).
 
 
     When setting a alignment tensor parameter, the residue number has no 
effect.  As the
     internal parameters of spherical alignment are {tm}, spheroidal 
alignment are {tm, Da,
     theta, phi}, and ellipsoidal alignment are {tm, Da, Dr, alpha, beta, 
gamma}, supplying
-    geometric parameters must be done in the following way.  If a single 
geometric parameter is
-    supplied, it must be one of tm, Diso, Da, Dr, or Dratio.  For the 
parameters Dpar, Dper, Dx,
-    Dy, and Dx, it is not possible to determine how to use the currently set 
values together
-    with the supplied value to calculate the new internal parameters.  For 
spheroidal alignment,
-    when supplying multiple geometric parameters, the set must belong to one 
of
-
-        {tm, Da},
-        {Diso, Da},
-        {tm, Dratio},
-        {Dpar, Dper},
-        {Diso, Dratio},
-
-    where either theta, phi, or both orientational parameters can be 
additionally supplied.  For
-    ellipsoidal alignment, again when supplying multiple geometric 
parameters, the set must
-    belong to one of
-
-        {tm, Da, Dr},
-        {Diso, Da, Dr},
-        {Dx, Dy, Dz},
-
-    where any number of the orientational parameters, alpha, beta, or gamma 
can be additionally
-    supplied.
+    geometric parameters must be done in the following way.  
+
+    If a single geometric parameter is supplied, it must be one of Axx, Ayy, 
Axy, Axz, Ayz.  For the
+    parameters Azz and Axxyy , it is not possible to determine how to use 
the currently set values
+    together with the supplied value to calculate the new internal 
parameters.  When supplying
+    multiple geometric parameters, the set must belong to one of
+
+        {Axx, Ayy, Axy, Axz, Ayz},
+        {Azz, Axxyy, Axy, Axz, Ayz}.
     """
 
     # Alias the current data pipe.
@@ -848,9 +833,9 @@
         elif geo_params[0] == 'Axz':
             cdp.align_tensor.Axz = geo_values[0]
 
-        # The single parameter Azy.
-        elif geo_params[0] == 'Azy':
-            cdp.align_tensor.Azy = geo_values[0]
+        # The single parameter Ayz.
+        elif geo_params[0] == 'Ayz':
+            cdp.align_tensor.Ayz = geo_values[0]
 
         # Cannot set the single parameter.
         else:




Related Messages


Powered by MHonArc, Updated Mon Nov 26 17:00:29 2007